@@ -108,18 +108,18 @@ impl Dashboard {
                     println_name_value("TPU Address:", &tpu.to_string());
                 }
                 if let Some(rpc) = contact_info.rpc {
-                    println_name_value("JSON RPC URL:", &format!("http://{}", rpc.to_string()));
+                    println_name_value("JSON RPC URL:", &format!("http://{}", rpc));
                 }
             }
 
             let progress_bar = new_spinner_progress_bar();
-            let mut snapshot_slot = None;
+            let mut snapshot_slot_info = None;
             for i in 0.. {
                 if exit.load(Ordering::Relaxed) {
                     break;
                 }
                 if i % 10 == 0 {
-                    snapshot_slot = rpc_client.get_snapshot_slot().ok();
+                    snapshot_slot_info = rpc_client.get_highest_snapshot_slot().ok();
                 }
 
                 match get_validator_stats(&rpc_client, &identity) {
@@ -144,10 +144,10 @@ impl Dashboard {
                             )
                         };
 
-                        progress_bar.set_message(&format!(
+                        progress_bar.set_message(format!(
                             "{}{}{}| \
                                     Processed Slot: {} | Confirmed Slot: {} | Finalized Slot: {} | \
-                                    Snapshot Slot: {} | \
+                                    Full Snapshot Slot: {} | Incremental Snapshot Slot: {} | \
                                     Transactions: {} | {}",
                             uptime,
                             if health == "ok" {
@@ -163,9 +163,17 @@ impl Dashboard {
                             processed_slot,
                             confirmed_slot,
                             finalized_slot,
-                            snapshot_slot
-                                .map(|s| s.to_string())
-                                .unwrap_or_else(|| "-".to_string()),
+                            snapshot_slot_info
+                                .as_ref()
+                                .map(|snapshot_slot_info| snapshot_slot_info.full.to_string())
+                                .unwrap_or_else(|| '-'.to_string()),
+                            snapshot_slot_info
+                                .as_ref()
+                                .map(|snapshot_slot_info| snapshot_slot_info
+                                    .incremental
+                                    .map(|incremental| incremental.to_string()))
+                                .flatten()
+                                .unwrap_or_else(|| '-'.to_string()),
                             transaction_count,
                             identity_balance
                         ));
@@ -173,7 +181,7 @@ impl Dashboard {
                     }
                     Err(err) => {
                         progress_bar
-                            .abandon_with_message(&format!("RPC connection failure: {}", err));
+                            .abandon_with_message(format!("RPC connection failure: {}", err));
                         break;
                     }
                 }
@@ -198,7 +206,7 @@ async fn wait_for_validator_startup(
             match admin_rpc_service::connect(ledger_path).await {
                 Ok(new_admin_client) => admin_client = Some(new_admin_client),
                 Err(err) => {
-                    progress_bar.set_message(&format!("Unable to connect to validator: {}", err));
+                    progress_bar.set_message(format!("Unable to connect to validator: {}", err));
                     thread::sleep(refresh_interval);
                     continue;
                 }
@@ -217,22 +225,21 @@ async fn wait_for_validator_startup(
                     }
                     .await
                     {
-                        Ok((None, _)) => progress_bar.set_message(&"RPC service not available"),
+                        Ok((None, _)) => progress_bar.set_message("RPC service not available"),
                         Ok((Some(rpc_addr), start_time)) => return Some((rpc_addr, start_time)),
                         Err(err) => {
                             progress_bar
-                                .set_message(&format!("Failed to get validator info: {}", err));
+                                .set_message(format!("Failed to get validator info: {}", err));
                         }
                     }
                 } else {
-                    progress_bar
-                        .set_message(&format!("Validator startup: {:?}...", start_progress));
+                    progress_bar.set_message(format!("Validator startup: {:?}...", start_progress));
                 }
             }
             Err(err) => {
                 admin_client = None;
                 progress_bar
-                    .set_message(&format!("Failed to get validator start progress: {}", err));
+                    .set_message(format!("Failed to get validator start progress: {}", err));
             }
         }
         thread::sleep(refresh_interval);
